@@ -29,8 +29,6 @@
 #endif
 
 #include <glib-object.h>
-/* This should be removed at some point. */
-#include "nautilus-extension-types.h"
 
 G_BEGIN_DECLS
 
