@@ -805,9 +805,13 @@ struct _NautilusFileUndoInfoCreate
 {
     NautilusFileUndoInfo parent_instance;
 
-    char *template;
+    union
+    {
+        char *template;
+        void *buffer;
+    };
     GFile *target_file;
-    gint length;
+    gsize length;
 };
 
 G_DEFINE_TYPE (NautilusFileUndoInfoCreate, nautilus_file_undo_info_create, NAUTILUS_TYPE_FILE_UNDO_INFO)
@@ -1011,12 +1015,23 @@ nautilus_file_undo_info_create_new (NautilusFileUndoOp op_type)
 void
 nautilus_file_undo_info_create_set_data (NautilusFileUndoInfoCreate *self,
                                          GFile                      *file,
-                                         const char                 *template,
+                                         const void                 *template,
                                          gsize                       length)
 {
+    NautilusFileUndoOp op_type = nautilus_file_undo_info_get_op_type (NAUTILUS_FILE_UNDO_INFO (self));
+
     self->target_file = g_object_ref (file);
-    self->template = g_strdup (template);
-    self->length = length;
+    if (op_type == NAUTILUS_FILE_UNDO_OP_CREATE_EMPTY_FILE)
+    {
+        /* Operation name is a misnomer, it still can hold data to write to
+         * the newly created file. */
+        self->buffer = g_memdup2 (template, length);
+        self->length = length;
+    }
+    else if (op_type == NAUTILUS_FILE_UNDO_OP_CREATE_FILE_FROM_TEMPLATE)
+    {
+        self->template = g_strdup (template);
+    }
 }
 
 /* rename */
@@ -1163,15 +1178,17 @@ batch_rename_strings_func (NautilusFileUndoInfo  *info,
                            gchar                **redo_description)
 {
     NautilusFileUndoInfoBatchRename *self = NAUTILUS_FILE_UNDO_INFO_BATCH_RENAME (info);
+    guint num_files = g_list_length (self->new_files);
+
 
     *undo_description = g_strdup_printf (ngettext ("Batch rename %d file",
                                                    "Batch rename %d files",
-                                                   g_list_length (self->new_files)),
-                                         g_list_length (self->new_files));
+                                                   num_files),
+                                         num_files);
     *redo_description = g_strdup_printf (ngettext ("Batch rename %d file",
                                                    "Batch rename %d files",
-                                                   g_list_length (self->new_files)),
-                                         g_list_length (self->new_files));
+                                                   num_files),
+                                         num_files);
 
     *undo_label = g_strdup (_("_Undo Batch Rename"));
     *redo_label = g_strdup (_("_Redo Batch Rename"));
@@ -1387,17 +1404,18 @@ starred_strings_func (NautilusFileUndoInfo  *info,
                       gchar                **redo_description)
 {
     NautilusFileUndoInfoStarred *self = NAUTILUS_FILE_UNDO_INFO_STARRED (info);
+    guint num_files = g_list_length (self->files);
 
     if (self->starred)
     {
         *undo_description = g_strdup_printf (ngettext ("Unstar %d file",
                                                        "Unstar %d files",
-                                                       g_list_length (self->files)),
-                                             g_list_length (self->files));
+                                                       num_files),
+                                             num_files);
         *redo_description = g_strdup_printf (ngettext ("Star %d file",
                                                        "Star %d files",
-                                                       g_list_length (self->files)),
-                                             g_list_length (self->files));
+                                                       num_files),
+                                             num_files);
         *undo_label = g_strdup (_("_Undo Starring"));
         *redo_label = g_strdup (_("_Redo Starring"));
     }
@@ -1405,12 +1423,12 @@ starred_strings_func (NautilusFileUndoInfo  *info,
     {
         *undo_description = g_strdup_printf (ngettext ("Star %d file",
                                                        "Star %d files",
-                                                       g_list_length (self->files)),
-                                             g_list_length (self->files));
+                                                       num_files),
+                                             num_files);
         *redo_description = g_strdup_printf (ngettext ("Unstar %d file",
                                                        "Unstar %d files",
-                                                       g_list_length (self->files)),
-                                             g_list_length (self->files));
+                                                       num_files),
+                                             num_files);
         *undo_label = g_strdup (_("_Undo Unstarring"));
         *redo_label = g_strdup (_("_Redo Unstarring"));
     }
