@@ -41,11 +41,6 @@ typedef gboolean (* NautilusWindowGoToCallback) (NautilusWindow *window,
                                                  GError *error,
                                                  gpointer user_data);
 
-typedef void (* NautilusWindowHandleExported) (NautilusWindow *window,
-                                               const char *handle,
-                                               guint xid,
-                                               gpointer user_data);
-
 /* window geometry */
 /* Min values are very small, and a Nautilus window at this tiny size is *almost*
  * completely unusable. However, if all the extra bits (sidebar, location bar, etc)
@@ -81,24 +76,8 @@ GList *              nautilus_window_get_slots             (NautilusWindow *wind
 void                 nautilus_window_slot_close            (NautilusWindow *window,
                                                             NautilusWindowSlot *slot);
 
-void                 nautilus_window_sync_location_widgets (NautilusWindow *window);
-
-void nautilus_window_reset_menus (NautilusWindow *window);
-
-AdwTabView * nautilus_window_get_tab_view (NautilusWindow *window);
-
 void     nautilus_window_show_about_dialog    (NautilusWindow *window);
 
-gboolean    nautilus_window_is_menu_visible       (NautilusWindow *toolbar);
-
-/* sync window GUI with current slot. Used when changing slots,
- * and when updating the slot state.
- */
-void nautilus_window_sync_allow_stop       (NautilusWindow *window,
-					    NautilusWindowSlot *slot);
-void nautilus_window_sync_title            (NautilusWindow *window,
-					    NautilusWindowSlot *slot);
-
 void nautilus_window_show_operation_notification (NautilusWindow *window,
                                                   gchar          *main_label,
                                                   GFile          *folder_to_open,
@@ -111,11 +90,6 @@ void nautilus_window_initialize_slot (NautilusWindow     *window,
                                       NautilusWindowSlot *slot,
                                       NautilusOpenFlags   flags);
 
-gboolean nautilus_window_export_handle (NautilusWindow *window,
-                                        NautilusWindowHandleExported callback,
-                                        gpointer user_data);
-void nautilus_window_unexport_handle (NautilusWindow *window);
-
 void nautilus_window_back_or_forward_in_new_tab (NautilusWindow              *window,
                                                  NautilusNavigationDirection  back);
 
